=======
Bolster
=======


.. image:: https://img.shields.io/pypi/v/bolster.svg
    :target: https://pypi.python.org/pypi/bolster

.. image:: https://travis-ci.com/andrewbolster/bolster.svg?branch=main
    :target: https://travis-ci.com/andrewbolster/bolster

.. image:: https://readthedocs.org/projects/bolster/badge/?version=latest
    :target: https://bolster.readthedocs.io/en/latest/?version=latest
    :alt: Documentation Status

.. image:: https://pyup.io/repos/github/andrewbolster/bolster/shield.svg
    :target: https://pyup.io/repos/github/andrewbolster/bolster/
    :alt: Updates

.. image:: https://requires.io/github/andrewbolster/bolster/requirements.svg?branch=main
    :target: https://requires.io/github/andrewbolster/bolster/requirements/?branch=main
    :alt: Requirements Status

Bolster's Brain, you've been warned

* Free software: GNU General Public License v3
* Documentation: https://bolster.readthedocs.io.


Features
--------

* Efficient tree/node traversal and iteration
* Datetime helpers
* Concurrecy Helpers
* Web safe Encapsulation/Decapsulation helpers
* `pandas`-esque `aggregate`/`transform_r` functions
* "Best Practice" AWS service handling

Data Sources
------------
* UK Companies House Listings
* NI House Price Index Data Wrangling

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
